# Twinn-ml-interface

[![PyPI Latest Release](https://img.shields.io/pypi/v/twinn-ml-interface.svg)](https://pypi.org/project/twinn-ml-interface/)
[![Downloads](https://static.pepy.tech/personalized-badge/twinn-ml-interface?period=month&units=international_system&left_color=black&right_color=orange&left_text=PyPI%20downloads%20per%20month)](https://pepy.tech/project/twinn-ml-interface)
[![License](https://img.shields.io/pypi/l/twinn-ml-interface.svg)](https://github.com/armenshamelian/twinn-ml-interface/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

**COMING SOON!**

Twinn-ml-interface is a Python package for *data contracts between machine learning code and infrastructure*.

Author: [Royal HaskoningDHV](https://global.royalhaskoningdhv.com/)

## Getting started
**COMING SOON!**

### Installation

The easiest way to install is package is using pip:
```
pip install twinn-ml-interface
```